@@ -29,10 +29,10 @@ import (
 
 var logger = logrus.New()
 
-func SetContext(desiredContext string, stores []store.KubeconfigStore, config *types.Config, stateDir string, noIndex bool, appendToHistory bool) (*string, error) {
+func SetContext(desiredContext string, stores []store.KubeconfigStore, config *types.Config, stateDir string, noIndex bool, appendToHistory bool) (*string, *string, error) {
 	c, err := pkg.DoSearch(stores, config, stateDir, noIndex)
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	var mError *multierror.Error
@@ -60,12 +60,12 @@ func SetContext(desiredContext string, stores []store.KubeconfigStore, config *t
 		if desiredContext == discoveredContext.Name || matchesContextWithoutPrefix || desiredContext == discoveredContext.Alias {
 			kubeconfigData, err := kubeconfigStore.GetKubeconfigForPath(discoveredContext.Path)
 			if err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 
 			kubeconfig, err := kubeconfigutil.NewKubeconfig(kubeconfigData)
 			if err != nil {
-				return nil, fmt.Errorf("failed to parse kubeconfig: %v", err)
+				return nil, nil, fmt.Errorf("failed to parse kubeconfig: %v", err)
 			}
 
 			originalContextBeforeAlias := ""
@@ -74,39 +74,36 @@ func SetContext(desiredContext string, stores []store.KubeconfigStore, config *t
 			}
 
 			if err := kubeconfig.SetContext(contextWithoutPrefix, originalContextBeforeAlias, kubeconfigStore.GetContextPrefix(discoveredContext.Path)); err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 
 			if err := kubeconfig.SetKubeswitchContext(desiredContext); err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 
 			tempKubeconfigPath, err := kubeconfig.WriteKubeconfigFile()
 			if err != nil {
-				return nil, fmt.Errorf("failed to write temporary kubeconfig file: %v", err)
+				return nil, nil, fmt.Errorf("failed to write temporary kubeconfig file: %v", err)
 			}
 
 			if appendToHistory {
 				// get namespace for current context
 				ns, err := kubeconfig.NamespaceOfContext(kubeconfig.GetCurrentContext())
 				if err != nil {
-					return nil, fmt.Errorf("failed to get namespace of current context: %v", err)
+					return nil, nil, fmt.Errorf("failed to get namespace of current context: %v", err)
 				}
 
 				if err := historyutil.AppendToHistory(desiredContext, ns); err != nil {
 					logger.Warnf("failed to append context to history file: %v", err)
 				}
 			}
-
-			// print kubeconfig path to std.out -> captured by calling bash script to set KUBECONFIG environment Variable
-			fmt.Print(tempKubeconfigPath)
-			return &tempKubeconfigPath, nil
+			return &tempKubeconfigPath, &desiredContext, nil
 		}
 	}
 
 	if mError != nil {
-		return nil, fmt.Errorf("context with name %q not found. Possibly due to errors: %v", desiredContext, mError.Error())
+		return nil, nil, fmt.Errorf("context with name %q not found. Possibly due to errors: %v", desiredContext, mError.Error())
 	}
 
-	return nil, fmt.Errorf("context with name %q not found", desiredContext)
+	return nil, nil, fmt.Errorf("context with name %q not found", desiredContext)
 }
