@@ -123,7 +123,9 @@ type Cache struct {
 
 type StoreConfigVault struct {
 	// VaultAPIAddress is the URL of the Vault API
-	VaultAPIAddress string `yaml:"vaultAPIAddress"`
+	VaultAPIAddress    string `yaml:"vaultAPIAddress"`
+	VaultEngineVersion string `yaml:"vaultEngineVersion"`
+	VaultKeyKubeconfig string `yaml:"vaultKeyKubeconfig"`
 }
 
 type StoreConfigGardener struct {
@@ -219,8 +221,8 @@ type GKEAuthentication struct {
 }
 
 type StoreConfigRancher struct {
-	// RancherAddress is the URL of the Rancher API, e.g. https://rancher.example.com/v3
-	RancherAddress string `yaml:"rancherAPIAddress"`
+	// RancherAPIAddress is the URL of the Rancher API, e.g. https://rancher.example.com/v3
+	RancherAPIAddress string `yaml:"rancherAPIAddress"`
 	// RancherToken is the token used to authenticate against the Rancher API, format: token-12abc:bmjlzslas......x4hv5ptc29wt4sfk
 	RancherToken string `yaml:"rancherToken"`
 }
